package com.chelvc.cloud.maintain.controller;

import com.chelvc.cloud.maintain.copier.UserCopier;
import com.chelvc.cloud.maintain.vo.UserVO;
import com.chelvc.cloud.uc.api.dto.UserDTO;
import com.chelvc.cloud.uc.api.param.UserModifyParam;
import com.chelvc.cloud.uc.api.service.UserService;
import com.chelvc.framework.base.annotation.UnifiedResponseBody;
import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.base.util.ErrorUtils;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * 会员接口
 *
 * @author 七仔
 * @date 2023/5/22
 */
@Validated
@RestController
@UnifiedResponseBody
public class CustomerController {
    @DubboReference
    private UserService userService;

    /**
     * 获取用户信息
     *
     * @return 用户信息
     */
    @GetMapping("/customer")
    public UserVO getCustomer() {
        UserDTO user = this.userService.getUser(SessionContextHolder.getId());
        ErrorUtils.requireResource(user, "用户不存在");
        return UserCopier.INSTANCE.copying(user);
    }

    /**
     * 修改用户信息
     *
     * @param param 修改参数
     */
    @PutMapping("/customer")
    public void updateCustomer(@RequestBody @Valid UserModifyParam param) {
        this.userService.updateUser(SessionContextHolder.getId(), param);
    }
}
