package com.chelvc.cloud.maintain.controller;

import com.chelvc.cloud.maintain.vo.SignIndexVO;
import com.chelvc.cloud.uc.api.constant.ScoreOrigin;
import com.chelvc.cloud.uc.api.dto.SignDTO;
import com.chelvc.cloud.uc.api.service.ScoreService;
import com.chelvc.cloud.uc.api.service.SignService;
import com.chelvc.framework.base.annotation.UnifiedResponseBody;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.util.ObjectUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 签到接口
 *
 * @author Woody
 * @date 2023/5/7
 */
@Validated
@RestController
@UnifiedResponseBody
public class SignController {
    @DubboReference
    private SignService signService;
    @DubboReference
    private ScoreService scoreService;

    /**
     * 用户签到
     */
    @PostMapping("/sign")
    public void sign() {
        this.signService.sign();
    }

    /**
     * 每日签到页面信息
     *
     * @return 每日签到页面信息
     */
    @GetMapping("/sign/index")
    public SignIndexVO getCustomerSign() {
        SignIndexVO sign = SignIndexVO.builder().build();
        SignDTO todaySign = this.signService.getTodaySign();
        if (ObjectUtils.isEmpty(todaySign) || todaySign.getSignDay() == null) {
            sign.setSignDay(0);
        } else {
            sign.setSignDay(todaySign.getSignDay());
        }
        sign.setSignScore(this.scoreService.countScoreValue(ScoreOrigin.SIGN.name()));
        return sign;
    }
}
